function f = rechteSeite(t,yy)
    x   = yy(1,1);
    y   = yy(2,1);
    phi = yy(3,1);

    vx   = yy(4,1);
    vy   = yy(5,1);
    om   = yy(6,1);

    //Kollisionskräfte sind zunächst keine vorhanden:
    Fkollisionx = 0;
    Fkollisiony = 0;
    Mkollision  = 0;
    
    //Die linke und rechte Antriebskraft wird aus den PWM-Signalen
    //mit einem Verstärkungsfaktor gebildet:
//    pwm_links  = 799;
    pwm_links  = PWM_L;
    pwm_rechts = PWM_R;
    Fantrieb_links  = pwm_links  * PWMFAKTOR;
    Fantrieb_rechts = pwm_rechts * PWMFAKTOR;

    //Die Antriebskräfte wirken in die Richtung, in die das Fahrzeug gerade orientiert ist:
    FanL = dr([Fantrieb_links;0],  phi);
    FanR = dr([Fantrieb_rechts;0], phi);

    //Vorbereitung der Dämpfungskräfte:
    //a) Verbindungsvektoren von S zu ABCD im Inertialkoordinatensystem
    rA = dr(PA,  phi);
    rB = dr(PB,  phi);
    rC = dr(PC,  phi);
    rD = dr(PD,  phi);
    //b) Aktuelle Geschwindigkeit in jedem Punkt ABCD bestimmen:
    //   vp = v + w x r
    vA = [vx;vy] + kv(om,rA); 
    vB = [vx;vy] + kv(om,rB); 
    vC = [vx;vy] + kv(om,rC); 
    vD = [vx;vy] + kv(om,rD); 
    //c) Dämpfungskräfte entgegen aktueller Geschw. im jeweiligen Punkt:
    FDampA = - DAMP*vA;
    FDampB = - DAMP*vB;
    FDampC = - DAMP*vC;
    FDampD = - DAMP*vD;

    //Reibkraft vorbereiten:
    //6N insgesamt, 1.5 pro Kraftangriffspunkt.
    //a) Skalare der Geschwindigkeitsanteile vorwärts und zur Seite bestimmen
    evorn = dr([1;0],  phi);
    eseit = dr([0;1],  phi);
    vAvorn = vA'*evorn;
    vAseit = vA'*eseit;
    vBvorn = vB'*evorn;
    vBseit = vB'*eseit;
    vCvorn = vC'*evorn;
    vCseit = vC'*eseit;
    vDvorn = vD'*evorn;
    vDseit = vD'*eseit;
    //Skalar zwischen +/-1.5 mit schmalem Übergang:
    FReibA = 1.5*(  -1/(1+exp(-1000*vAvorn))*2+1  )*evorn +1.5*(  -1/(1+exp(-1000*vAseit))*2+1  )*eseit;
    FReibB = 1.5*(  -1/(1+exp(-1000*vBvorn))*2+1  )*evorn +1.5*(  -1/(1+exp(-1000*vBseit))*2+1  )*eseit;
    FReibC = 1.5*(  -1/(1+exp(-1000*vCvorn))*2+1  )*evorn +1.5*(  -1/(1+exp(-1000*vCseit))*2+1  )*eseit;
    FReibD = 1.5*(  -1/(1+exp(-1000*vDvorn))*2+1  )*evorn +1.5*(  -1/(1+exp(-1000*vDseit))*2+1  )*eseit;



    //Die Kräfte setzen sich aus den einzelnen Komponenten zusammen:
    FA = 0.5*FanR + FDampA + FReibA;
    FB = 0.5*FanL + FDampB + FReibB;
    FC = 0.5*FanL + FDampC + FReibC;
    FD = 0.5*FanR + FDampD + FReibD;

    //Momente, die durch die Kräfte in ABCD wirken bestimmen:
    MA = kr(rA,FA);
    MB = kr(rB,FB);
    MC = kr(rC,FC);
    MD = kr(rD,FD);

    //Aufspaltung der Kräfte in x/y-Komponenten:
    FAx = FA(1);
    FAy = FA(2);
    FBx = FB(1);
    FBy = FB(2);
    FCx = FC(1);
    FCy = FC(2);
    FDx = FD(1);
    FDy = FD(2);

    f(1,1) = vx;
    f(2,1) = vy;
    f(3,1) = om;

    f(4,1) = (FAx+FBx+FCx+FDx  + Fkollisionx)/m;
    f(5,1) = (FAy+FBy+FCy+FDy  + Fkollisiony)/m;
    f(6,1) = (MA +MB +MC +MD   + Mkollision)/J;

endfunction